import { _ as __awaiter, a as __generator } from './_tslib-47e48da1.js';
import { i as isArguments_1, _ as _arrayPush } from './isArguments-b758e3e7.js';
import { _ as _Symbol, i as isArray_1 } from './trimEnd-608117d4.js';
import fse from 'fs-extra';
import main$1 from './normalizePath.js';

var Symbol = _Symbol,
    isArguments = isArguments_1,
    isArray = isArray_1;

/** Built-in value references. */
var spreadableSymbol = Symbol ? Symbol.isConcatSpreadable : undefined;

/**
 * Checks if `value` is a flattenable `arguments` object or array.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is flattenable, else `false`.
 */
function isFlattenable$1(value) {
  return isArray(value) || isArguments(value) ||
    !!(spreadableSymbol && value && value[spreadableSymbol]);
}

var _isFlattenable = isFlattenable$1;

var arrayPush = _arrayPush,
    isFlattenable = _isFlattenable;

/**
 * The base implementation of `_.flatten` with support for restricting flattening.
 *
 * @private
 * @param {Array} array The array to flatten.
 * @param {number} depth The maximum recursion depth.
 * @param {boolean} [predicate=isFlattenable] The function invoked per iteration.
 * @param {boolean} [isStrict] Restrict to values that pass `predicate` checks.
 * @param {Array} [result=[]] The initial result value.
 * @returns {Array} Returns the new flattened array.
 */
function baseFlatten$1(array, depth, predicate, isStrict, result) {
  var index = -1,
      length = array.length;

  predicate || (predicate = isFlattenable);
  result || (result = []);

  while (++index < length) {
    var value = array[index];
    if (depth > 0 && predicate(value)) {
      if (depth > 1) {
        // Recursively flatten arrays (susceptible to call stack limits).
        baseFlatten$1(value, depth - 1, predicate, isStrict, result);
      } else {
        arrayPush(result, value);
      }
    } else if (!isStrict) {
      result[result.length] = value;
    }
  }
  return result;
}

var _baseFlatten = baseFlatten$1;

var baseFlatten = _baseFlatten;

/**
 * Flattens `array` a single level deep.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to flatten.
 * @returns {Array} Returns the new flattened array.
 * @example
 *
 * _.flatten([1, [2, [3, [4]], 5]]);
 * // => [1, 2, [3, [4]], 5]
 */
function flatten(array) {
  var length = array == null ? 0 : array.length;
  return length ? baseFlatten(array, 1) : [];
}

var flatten_1 = flatten;

var main = function () {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return __awaiter(void 0, void 0, void 0, function () {
        var group, _a, group_1, source;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    group = flatten_1(args).map(main$1);
                    if (!group.length)
                        return [2, false];
                    _a = 0, group_1 = group;
                    _b.label = 1;
                case 1:
                    if (!(_a < group_1.length)) return [3, 4];
                    source = group_1[_a];
                    if (source.includes('*'))
                        throw new Error("invalid path '".concat(source, "'"));
                    return [4, fse.pathExists(source)];
                case 2:
                    if (!(_b.sent()))
                        return [2, false];
                    _b.label = 3;
                case 3:
                    _a++;
                    return [3, 1];
                case 4: return [2, true];
            }
        });
    });
};

export { flatten_1 as f, main as m };
