import { _ as __awaiter, a as __generator } from './_tslib-47e48da1.js';
import archiver from 'archiver';
import main$5 from './toArray.js';
import main$1, { renderPath } from './echo.js';
import fs from 'fs';
import main$8 from './getBasename.js';
import main$7 from './getDirname.js';
import main$4 from './glob.js';
import kleur from 'kleur';
import main$6 from './normalizePath.js';
import main$3 from './toString.js';
import { h as _baseIndexOf, j as _baseToString, k as _castSlice, l as _charsEndIndex, m as _stringToArray, f as toString_1 } from './trimEnd-608117d4.js';
import { _ as _baseTrim } from './_baseTrim-ca68e45e.js';
import main$2 from './wrapList.js';
import './home.js';
import 'os';
import './root.js';
import './getType.js';
import './getName.js';
import 'path';
import 'fast-glob';

var baseIndexOf = _baseIndexOf;

/**
 * Used by `_.trim` and `_.trimStart` to get the index of the first string symbol
 * that is not found in the character symbols.
 *
 * @private
 * @param {Array} strSymbols The string symbols to inspect.
 * @param {Array} chrSymbols The character symbols to find.
 * @returns {number} Returns the index of the first unmatched string symbol.
 */
function charsStartIndex$1(strSymbols, chrSymbols) {
  var index = -1,
      length = strSymbols.length;

  while (++index < length && baseIndexOf(chrSymbols, strSymbols[index], 0) > -1) {}
  return index;
}

var _charsStartIndex = charsStartIndex$1;

var baseToString = _baseToString,
    baseTrim = _baseTrim,
    castSlice = _castSlice,
    charsEndIndex = _charsEndIndex,
    charsStartIndex = _charsStartIndex,
    stringToArray = _stringToArray,
    toString = toString_1;

/**
 * Removes leading and trailing whitespace or specified characters from `string`.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to trim.
 * @param {string} [chars=whitespace] The characters to trim.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {string} Returns the trimmed string.
 * @example
 *
 * _.trim('  abc  ');
 * // => 'abc'
 *
 * _.trim('-_-abc-_-', '_-');
 * // => 'abc'
 *
 * _.map(['  foo  ', '  bar  '], _.trim);
 * // => ['foo', 'bar']
 */
function trim(string, chars, guard) {
  string = toString(string);
  if (string && (guard || chars === undefined)) {
    return baseTrim(string);
  }
  if (!string || !(chars = baseToString(chars))) {
    return string;
  }
  var strSymbols = stringToArray(string),
      chrSymbols = stringToArray(chars),
      start = charsStartIndex(strSymbols, chrSymbols),
      end = charsEndIndex(strSymbols, chrSymbols) + 1;

  return castSlice(strSymbols, start, end).join('');
}

var trim_1 = trim;

var execute = function (listSource, target, option) { return __awaiter(void 0, void 0, void 0, function () {
    var base, filename, listResource;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                base = option.base, filename = option.filename;
                return [4, main$4(listSource)];
            case 1:
                listResource = _a.sent();
                return [4, new Promise(function (resolve) {
                        var output = fs.createWriteStream("".concat(target, "/").concat(filename));
                        var archive = archiver('zip', {
                            zlib: {
                                level: 9,
                            },
                        });
                        var message = '';
                        archive.on('end', function () { return resolve(true); });
                        archive.on('entry', function (e) { return (message = renderPath("".concat(e.name))); });
                        archive.on('error', function (e) {
                            console.log(kleur.red(e.message));
                            throw e;
                        });
                        archive.on('progress', function (e) {
                            if (!message)
                                return;
                            var gray = kleur.gray("".concat(Math.round((e.fs.processedBytes * 100) / e.fs.totalBytes), "%"));
                            var magenta = kleur.magenta(message);
                            console.log("".concat(gray, " ").concat(magenta));
                            message = '';
                        });
                        archive.on('warning', function (e) {
                            console.log(kleur.red(e.message));
                            throw e;
                        });
                        archive.pipe(output);
                        for (var _i = 0, listResource_1 = listResource; _i < listResource_1.length; _i++) {
                            var src = listResource_1[_i];
                            var name_1 = src.replace(base, '');
                            archive.file(src, { name: name_1 });
                        }
                        archive.finalize();
                    })];
            case 2:
                _a.sent();
                return [2];
        }
    });
}); };
var toArray = function (source, target, option) {
    var listSource = main$5(source).map(main$6);
    var pathTarget = main$6(target || main$7(listSource[0]).replace(/\*/g, ''));
    var _a = typeof option === 'string'
        ? ['', option]
        : [option.base || '', option.filename || ''], base = _a[0], filename = _a[1];
    base = main$6(base || getBase(listSource));
    if (!filename)
        filename = "".concat(main$8(pathTarget), ".zip");
    return [
        listSource,
        pathTarget,
        {
            base: base,
            filename: filename,
        },
    ];
};
var getBase = function (listSource) {
    var source = listSource[0];
    if (source.includes('*'))
        return trim_1(source.replace(/\*.*/u, ''), '/');
    return main$7(source);
};
var main = function (source, target, option) {
    if (target === void 0) { target = ''; }
    if (option === void 0) { option = ''; }
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, execute.apply(void 0, toArray(source, target, option))];
                case 1:
                    _a.sent();
                    main$1('zip', "zipped ".concat(main$2(source), " to '").concat(target, "', as '").concat(main$3(option), "'"));
                    return [2];
            }
        });
    });
};

export { main as default };
